@@ -10,12 +10,12 @@
 ## IMPORTS ##
 
 import json
+
+from qsharp.utils import try_import_qutip
 import numpy as np
 import os
 import pytest
 import qsharp
-import qsharp.experimental
-qsharp.experimental.enable_noisy_simulation()
 from .utils import set_environment_variables
 
 print ( qsharp.component_versions() )
@@ -26,10 +26,7 @@ print ( qsharp.component_versions() )
 def session_setup():
     set_environment_variables()
 
-try:
-    import qutip as qt
-except ImportError:
-    qt = None
+qt = try_import_qutip(warn=True, optional=True)
 
 skip_if_no_qutip = pytest.mark.skipif(qt is None, reason="Test requires QuTiP.")
 
@@ -160,17 +157,6 @@ def test_paulis():
     assert r[0] == [qsharp.Pauli.X, qsharp.Pauli.Z, qsharp.Pauli.Z]
     assert r[1] == qsharp.Pauli.Z
 
-@skip_if_no_workspace
-def test_estimate():
-    """
-    Verifies that resource estimation works.
-    """
-    from Microsoft.Quantum.SanityTests import HelloAgain
-    r = HelloAgain.estimate_resources(count=4, name="estimate test")
-    assert r['Measure'] == 8
-    assert r['QubitClifford'] == 1
-    assert r['BorrowedWidth'] == 0
-
 @skip_if_no_workspace
 def test_trace():
     """
@@ -269,7 +255,7 @@ def test_projects(tmp_path):
     temp_project_path.write_text(f'''
         <Project Sdk="Microsoft.Quantum.Sdk/0.12.20072031">
             <PropertyGroup>
-                <TargetFramework>netstandard2.1</TargetFramework>
+                <TargetFramework>net6.0</TargetFramework>
                 <IncludeQsharpCorePackages>false</IncludeQsharpCorePackages>
             </PropertyGroup>
         </Project>
@@ -352,9 +338,9 @@ class TestCaptureDiagnostics:
             }
         """)
 
-        qsharp.experimental.set_noise_model_by_name('ideal')
-        qsharp.config['experimental.simulators.nQubits'] = 2
-        qsharp.config['experimental.simulators.representation'] = 'mixed'
+        qsharp.set_noise_model_by_name('ideal')
+        qsharp.config['simulators.noisy.nQubits'] = 2
+        qsharp.config['simulators.noisy.representation'] = 'mixed'
 
         with qsharp.capture_diagnostics(as_qobj=True) as captured:
             dump_plus.simulate_noise()
